pub trait Base<Err> {
// Required methods
fn write_command(
&mut self,
command: Command,
data: Option<u16>,
) -> Result<(), Error<Err>>;
fn read_command(
&mut self,
command: Command,
data: &mut [u8],
) -> Result<(), Error<Err>>;
}Expand description
Base API for reading and writing to the device This should not be required by consumers, but is exposed to support alternate use (or in future provide ModBus support)
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".